/****************************************************************/
/* File:        main.c                                          */
/****************************************************************/
/* Author:     Data Converter Plug-In Development Team          */
/*             <dcp-support@list.ti.com>                        */
/*                                                              */
/* Created:    2006  By Texas Instruments Deutschland GmbH     */
/*                                                              */
/* Version:    2.0  /  May 2006                                 */
/****************************************************************/
/* Description: Demo program for the ADS8412 connected to a     */
/*              C6713 DSK                                       */
/*                                                              */
/*              The program samples BUFFER_SIZE values and      */
/*              places the values into the r_buffer1 and        */
/*              r_buffer2 arrays.                               */
/*              The variable Ads8412_1.xferInProgress can be    */
/*              used to track the progress of the transfer (it  */
/*              will be 1 while a transfer is in progress).     */
/*                                                              */
/*              The H/W interface between the ASD8412 and the   */
/*              DSP is defined using the Data Converter Support */
/*              tool in Code Composer Studio, which creates the */
/*              software driver for the low level data transfer */
/*                                                              */
/*              The following settings are made in the DSP/BIOS */
/*              configuration tool:                             */
/*              - Mapping of the interrupt for the EDMA         */
/*                transfer complete interrupt to:               */
/*                    _DCPDISP_dispatchEdmaIsr                  */
/*                                                              */
/*              The data read can be viewed by setting a probe- */
/*              point at the dc_rblock(); line in the main      */
/*              routine and connecting it to a graph window     */
/*              with r_buffer1 as the start address, a length of*/
/*              BUFFERSIZE (for both read and display size) and */
/*              a data size of 16 bit signed integer            */
/****************************************************************/
/* Jumper settings for the 5-6K Interface Board (Rev B):        */
/*              W1: open         W4: 2-3                        */
/*              W2: 2-3          W5: 2-3                        */
/*              W3: 2-3          W6: 1-2                        */
/*              W7: 2-3          All others: don't care         */
/*              J13: INTb        J14: TOUTb                     */
/*                                                              */
/* Power connections on the 5-6K Interface Board:               */
/*              J1: +/- 7V      J2: +5V                         */
/*                                                              */
/* Jumper settings for the ADS8412 EVM:                         */
/*              W1: 1-2                                         */
/*              W2: 1-2 ==> RD\ address =     0xA0024000        */
/*              W3: 2-3                                         */
/*              W4: 1-2 ==> RESET\ address =  0xA0034000        */
/*              W5: open                                        */
/*                                                              */
/*              J3: Pin 1-2 connected (CS\ tied to GND)         */
/*                                                              */
/* Additional connection needed on the ADS8412 EVM:             */
/*              Connect P2 pin 17 to J3 pin 5                   */
/*                                                              */
/* Analog signal connections on the ADS8412 EVM:                */
/*              Apply signal to either P1 pin 2 & 17 or to J2   */
/*              Analog signal settings:                         */
/*               - Frequency: 3.5kHz                            */
/*               - Amplitude: +4V                               */
/*               - Offset:    0V                                */
/* All the H/W settings above translate to the following        */
/* settings in the data converter support tool:                 */
/*              DSP Tab:     DSP-Type:           TMS320C6713BGDP*/
/*                           DSP Clock:          225 MHz        */
/*              ADS8412 Tab: RD# Address:        0xA0024000     */
/*                           Timer:              Timer 1        */
/*                           Interrupt:          n/a            */
/*                           Program EMIF:       Checked        */
/*                           Conversion Rate:    1875.000kHz    */
/****************************************************************/

/* include files for the data converter plug-in                 */
#include "dc_conf.h"
#include "t8412_fn.h"

/* include files for the chip support library                   */
#include <csl.h>
#include <csl_cache.h>
#include <csl_irq.h>

/* miscellaneous include files                                  */
#include <stdio.h>

/* define the size of the buffer                                */
#define BUFFER_SIZE (1024)

/* create the buffer and align it to a cache friendly boundary  */
#pragma DATA_ALIGN (r_buffer1, CACHE_L2_LINESIZE)
#pragma DATA_ALIGN (r_buffer2, CACHE_L2_LINESIZE)
unsigned short r_buffer1[BUFFER_SIZE];
unsigned short r_buffer2[BUFFER_SIZE];

volatile int iAdsBusy;

/****************************************************************/
/* callback(): Will be called at the end of the transfer and    */
/*             will reset the semaphore for the transfer        */
/****************************************************************/
void callback(void *pDC)
{
   TADS8412 *pADS = pDC;
   volatile unsigned int uiAddress;
   volatile unsigned int uiLength;
   int iIndex;

   /* get the address of the finished buffer                    */
   if (pADS->xferBuffer[0].uiStatus == 2)
      iIndex = 0;
   else
      iIndex = 1;

   uiAddress = (unsigned int)pADS->xferBuffer[iIndex].usBufPtr;
   uiLength = pADS->xferBuffer[iIndex].uiBufSize;

   if (pADS->xferInProgress == 1)
       iAdsBusy = 0;          /* reset semaphore for transfer   */
}


/****************************************************************/
/* main(): Configures the interface to the ADS8412              */
/*         Finally, issues a block read command to the converter*/
/*         and waits for the completion                         */
/****************************************************************/
int main(void)
{
    int iStatus;
    int i;

    for(i=0; i < BUFFER_SIZE; i++)
        r_buffer1[i] = 0;
    for(i=0; i < BUFFER_SIZE; i++)
        r_buffer2[i] = 0;

    /* call the configuration of the ADS and the interface      */
    iStatus = dc_configure(&Ads8412_1);

    if (!(iStatus == TIDC_NO_ERR))  /* something went wrong     */
    {
        fprintf(stderr, "\nError: ADS8412 init failed!\n");
        abort();
    }

    IRQ_nmiEnable();          /* enable the non-maskable int    */
    IRQ_globalEnable();       /* enable interrupts globally     */

    iAdsBusy = 0;

    while(1)                     /* loop forever                */
    {
        while(iAdsBusy);         /*transfer in progress?        */

        /* issue a read block command to the converter          */
        dc_rblock(&Ads8412_1,    /* data converter object       */
                  r_buffer1,     /* address of the target buffer*/
                  BUFFER_SIZE,   /* size of the target buffer   */
                  callback);     /* callback function           */
        iAdsBusy = 1;
        dc_rblock(&Ads8412_1,    /* data converter object       */
                  r_buffer2,     /* address of the target buffer*/
                  BUFFER_SIZE,   /* size of the target buffer   */
                  callback);     /* callback function           */
        iAdsBusy = 1;
    }
}
/****************************************************************/
/* End of main.c                                                */
/****************************************************************/
